const core = @import("core");
const std = @import("std");
const sys = @import("./sys.zig");

///
/// Application entry-point.
///
pub fn main() anyerror!void {
    return nosuspend await async sys.display(anyerror, runEngine);
}

///
/// Runs the game engine.
///
fn runEngine(app: *sys.App, graphics: *sys.Graphics) anyerror!void {
    {
        const path = try sys.Path.from(&.{"ona.lua"});
        var file_reader = try app.data.openFileReader(path);

        defer file_reader.close();

        const file_size = (try app.data.query(path)).length;
        const allocator = sys.threadSafeAllocator();
        const buffer = (try core.io.makeMany(u8, allocator, file_size))[0 .. file_size];

        defer core.io.free(allocator, buffer);

        if ((try file_reader.read(buffer)) != file_size) return error.ScriptLoadFailure;

        app.log(.debug, buffer);
    }

    while (graphics.poll()) |_| {
        graphics.present();
    }
}

test {
    _ = sys;
}
